@@ -16,11 +16,10 @@ import os
 from typing import Optional, Dict, Any
 from iatoolkit.repositories.database_manager import DatabaseManager
 from werkzeug.middleware.proxy_fix import ProxyFix
-
-
 from injector import Binder, singleton, Injector
 from importlib.metadata import version as _pkg_version, PackageNotFoundError
 
+IATOOLKIT_VERSION = "0.58.10"
 
 # global variable for the unique instance of IAToolkit
 _iatoolkit_instance: Optional['IAToolkit'] = None
@@ -53,7 +52,7 @@ class IAToolkit:
         self.app = None
         self.db_manager = None
         self._injector = None
-        self.version = "0.0.0+dev"
+        self.version = IATOOLKIT_VERSION
 
     @classmethod
     def get_instance(cls) -> 'IAToolkit':
@@ -153,14 +152,12 @@ class IAToolkit:
         except PackageNotFoundError:
             pass
 
-        self.app.wsgi_app = ProxyFix(self.app.wsgi_app, x_proto=1)
 
         self.app.config.update({
             'VERSION': self.version,
-            'SERVER_NAME': domain,
             'SECRET_KEY': self._get_config_value('FLASK_SECRET_KEY', 'iatoolkit-default-secret'),
-            'SESSION_COOKIE_SAMESITE': "None" if is_https else "Lax",
-            'SESSION_COOKIE_SECURE': is_https,
+            'SESSION_COOKIE_SAMESITE': "None",
+            'SESSION_COOKIE_SECURE': True,
             'SESSION_PERMANENT': False,
             'SESSION_USE_SIGNER': True,
             'JWT_SECRET_KEY': self._get_config_value('JWT_SECRET_KEY', 'iatoolkit-jwt-secret'),
@@ -171,6 +168,9 @@ class IAToolkit:
         if parsed_url.scheme == 'https':
             self.app.config['PREFERRED_URL_SCHEME'] = 'https'
 
+        # 2. ProxyFix para no tener problemas con iframes y rutas
+        self.app.wsgi_app = ProxyFix(self.app.wsgi_app, x_proto=1)
+
         # Configuración para tokenizers en desarrollo
         if is_dev:
             os.environ["TOKENIZERS_PARALLELISM"] = "false"
@@ -187,6 +187,15 @@ class IAToolkit:
         self.db_manager.create_all()
         logging.info("✅ Base de datos configurada correctamente")
 
+        @self.app.teardown_appcontext
+        def remove_session(exception=None):
+            """
+            Flask calls this after each request.
+            It ensures the SQLAlchemy session is properly closed
+            and the DB connection is returned to the pool.
+            """
+            self.db_manager.scoped_session.remove()
+
     def _setup_redis_sessions(self):
         redis_url = self._get_config_value('REDIS_URL')
         if not redis_url:
@@ -221,6 +230,7 @@ class IAToolkit:
         default_origins = [
             "http://localhost:5001",
             "http://127.0.0.1:5001",
+            "https://portal-interno.maxxa.cl",
             os.getenv('IATOOLKIT_BASE_URL')
         ]
 
@@ -256,7 +266,6 @@ class IAToolkit:
             self._bind_repositories(binder)
             self._bind_services(binder)
             self._bind_infrastructure(binder)
-            self._bind_views(binder)
 
             logging.info("✅ Dependencias configuradas correctamente")
 
@@ -308,34 +317,21 @@ class IAToolkit:
         binder.bind(Dispatcher, to=Dispatcher)
         binder.bind(BrandingService, to=BrandingService)
 
-
     def _bind_infrastructure(self, binder: Binder):
         from iatoolkit.infra.llm_client import llmClient
         from iatoolkit.infra.llm_proxy import LLMProxy
         from iatoolkit.infra.google_chat_app import GoogleChatApp
         from iatoolkit.infra.mail_app import MailApp
-        from iatoolkit.common.auth import IAuthentication
+        from iatoolkit.services.auth_service import AuthService
         from iatoolkit.common.util import Utility
 
-
-
         binder.bind(LLMProxy, to=LLMProxy, scope=singleton)
         binder.bind(llmClient, to=llmClient, scope=singleton)
         binder.bind(GoogleChatApp, to=GoogleChatApp)
         binder.bind(MailApp, to=MailApp)
-        binder.bind(IAuthentication, to=IAuthentication)
+        binder.bind(AuthService, to=AuthService)
         binder.bind(Utility, to=Utility)
 
-    def _bind_views(self, binder: Binder):
-        """Vincula las vistas después de que el injector ha sido creado"""
-        from iatoolkit.views.llmquery_view import LLMQueryView
-        from iatoolkit.views.home_view import HomeView
-
-        binder.bind(HomeView, to=HomeView)
-        binder.bind(LLMQueryView, to=LLMQueryView)
-
-        logging.info("✅ Views configuradas correctamente")
-
     def _setup_additional_services(self):
         Bcrypt(self.app)
 
@@ -373,12 +369,20 @@ class IAToolkit:
         @self.app.context_processor
         def inject_globals():
             from iatoolkit.common.session_manager import SessionManager
+            from iatoolkit.services.profile_service import ProfileService
+
+            profile_service = self._injector.get(ProfileService)
+            user_profile = profile_service.get_current_session_info().get('profile', {})
+
             return {
                 'url_for': url_for,
                 'iatoolkit_version': self.version,
                 'app_name': 'IAToolkit',
-                'user': SessionManager.get('user'),
-                'user_company': SessionManager.get('company_short_name'),
+                'user_identifier': SessionManager.get('user_identifier'),
+                'company_short_name': SessionManager.get('company_short_name'),
+                'user_is_local': user_profile.get('user_is_local'),
+                'user_email': user_profile.get('user_email'),
+                'iatoolkit_base_url': os.environ.get('IATOOLKIT_BASE_URL', ''),
             }
 
     def _get_default_static_folder(self) -> str:
