@@ -5,18 +5,18 @@
 
 from injector import inject
 from iatoolkit.repositories.profile_repo import ProfileRepo
+from iatoolkit.services.dispatcher_service import Dispatcher
 from iatoolkit.repositories.models import User, Company, ApiKey
 from flask_bcrypt import check_password_hash
 from iatoolkit.common.session_manager import SessionManager
+from iatoolkit.services.user_session_context_service import UserSessionContextService
 from flask_bcrypt import Bcrypt
 from iatoolkit.infra.mail_app import MailApp
 import random
-import logging
 import re
 import secrets
 import string
-from datetime import datetime, timezone
-from iatoolkit.services.user_session_context_service import UserSessionContextService
+from iatoolkit.services.dispatcher_service import Dispatcher
 
 
 class ProfileService:
@@ -24,8 +24,10 @@ class ProfileService:
     def __init__(self,
                  profile_repo: ProfileRepo,
                  session_context_service: UserSessionContextService,
+                 dispatcher: Dispatcher,
                  mail_app: MailApp):
         self.profile_repo = profile_repo
+        self.dispatcher = dispatcher
         self.session_context = session_context_service
         self.mail_app = mail_app
         self.bcrypt = Bcrypt()
@@ -42,7 +44,7 @@ class ProfileService:
             if not check_password_hash(user.password, password):
                 return {'success': False, "message": "Contraseña inválida"}
 
-            company = self.get_company_by_short_name(company_short_name)
+            company = self.profile_repo.get_company_by_short_name(company_short_name)
             if not company:
                 return {'success': False, "message": "Empresa no encontrada"}
 
@@ -54,34 +56,89 @@ class ProfileService:
                 return {'success': False,
                         "message": "Tu cuenta no ha sido verificada. Por favor, revisa tu correo."}
 
-            # save user data into session manager
-            self.set_user_session(user=user, company=company)
+            # 1. Build the local user profile dictionary here.
+            # the user_profile variables are used on the LLM templates also (see in query_main.prompt)
+            user_identifier = user.email             # no longer de ID
+            user_profile = {
+                "user_email": user.email,
+                "user_fullname": f'{user.first_name} {user.last_name}',
+                "user_is_local": True,
+                "extras": {}
+            }
 
-            return {'success': True, "user": user, "message": "Login exitoso"}
+            # 2. create user_profile in context
+            self.save_user_profile(company, user_identifier, user_profile)
+
+            # 3. create the web session
+            self.set_session_for_user(company.short_name, user_identifier)
+            return {'success': True, "user_identifier": user_identifier, "message": "Login exitoso"}
         except Exception as e:
             return {'success': False, "message": str(e)}
 
+    def create_external_user_profile_context(self, company: Company, user_identifier: str):
+        """
+        Public method for views to create a user profile context for an external user.
+        """
+        # 1. Fetch the external user profile via Dispatcher.
+        external_user_profile = self.dispatcher.get_user_info(
+            company_name=company.short_name,
+            user_identifier=user_identifier
+        )
 
-    def set_user_session(self, user: User, company: Company):
-        SessionManager.set('user_id', user.id)
-        SessionManager.set('company_id', company.id)
-        SessionManager.set('company_short_name', company.short_name)
+        # 2. Call the session creation helper with external_user_id as user_identifier
+        self.save_user_profile(
+            company=company,
+            user_identifier=user_identifier,
+            user_profile=external_user_profile)
 
-        # save user data into session manager
-        user_data = {
-            "id": user.id,
-            "email": user.email,
-            "user_fullname": f'{user.first_name} {user.last_name}',
-            "company_id": company.id,
-            "company": company.name,
-            "company_short_name": company.short_name,
-            "user_is_local": True,       # origin of data
-            "extras": {}                 # company specific data
+    def save_user_profile(self, company: Company, user_identifier: str, user_profile: dict):
+        """
+        Private helper: Takes a pre-built profile, saves it to Redis, and sets the Flask cookie.
+        """
+        user_profile['company_short_name'] = company.short_name
+        user_profile['user_identifier'] = user_identifier
+        user_profile['id'] = user_identifier
+        user_profile['company_id'] = company.id
+        user_profile['company'] = company.name
+
+        # save user_profile in Redis session
+        self.session_context.save_profile_data(company.short_name, user_identifier, user_profile)
+
+    def set_session_for_user(self, company_short_name: str, user_identifier:str ):
+        # save a min Flask session cookie for this user
+        SessionManager.set('company_short_name', company_short_name)
+        SessionManager.set('user_identifier', user_identifier)
+
+    def get_current_session_info(self) -> dict:
+        """
+         Gets the current web user's profile from the unified session.
+         This is the standard way to access user data for web requests.
+         """
+        # 1. Get identifiers from the simple Flask session cookie.
+        user_identifier = SessionManager.get('user_identifier')
+        company_short_name = SessionManager.get('company_short_name')
+
+        if not user_identifier or not company_short_name:
+            # No authenticated web user.
+            return {}
+
+        # 2. Use the identifiers to fetch the full, authoritative profile from Redis.
+        profile = self.session_context.get_profile_data(company_short_name, user_identifier)
+
+        return {
+            "user_identifier": user_identifier,
+            "company_short_name": company_short_name,
+            "profile": profile
         }
-        SessionManager.set('user', user_data)
 
-        # save time session was activated (in timestamp format)
-        SessionManager.set('last_activity', datetime.now(timezone.utc).timestamp())
+    def get_profile_by_identifier(self, company_short_name: str, user_identifier: str) -> dict:
+        """
+        Fetches a user profile directly by their identifier, bypassing the Flask session.
+        This is ideal for API-side checks.
+        """
+        if not company_short_name or not user_identifier:
+            return {}
+        return self.session_context.get_profile_data(company_short_name, user_identifier)
 
 
     def signup(self,
@@ -95,7 +152,7 @@ class ProfileService:
         try:
 
             # get company info
-            company = self.get_company_by_short_name(company_short_name)
+            company = self.profile_repo.get_company_by_short_name(company_short_name)
             if not company:
                 return {"error": f"la empresa {company_short_name} no existe"}
 
@@ -240,6 +297,9 @@ class ProfileService:
     def get_company_by_short_name(self, short_name: str) -> Company:
         return self.profile_repo.get_company_by_short_name(short_name)
 
+    def get_active_api_key_entry(self, api_key_value: str) -> ApiKey | None:
+        return self.profile_repo.get_active_api_key_entry(api_key_value)
+
     def new_api_key(self, company_short_name: str):
         company = self.get_company_by_short_name(company_short_name)
         if not company:
