@@ -4,8 +4,9 @@
 # IAToolkit is open source software.
 
 from flask.views import MethodView
-from flask import render_template, request
+from flask import render_template, request, url_for, session, redirect
 from iatoolkit.services.profile_service import ProfileService
+from iatoolkit.services.branding_service import BrandingService
 from itsdangerous import URLSafeTimedSerializer, SignatureExpired
 from flask_bcrypt import Bcrypt
 from injector import inject
@@ -14,8 +15,11 @@ import os
 
 class ChangePasswordView(MethodView):
     @inject
-    def __init__(self, profile_service: ProfileService):
+    def __init__(self,
+                 profile_service: ProfileService,
+                 branding_service: BrandingService):
         self.profile_service = profile_service
+        self.branding_service = branding_service # 3. Guardar la instancia
 
         self.serializer = URLSafeTimedSerializer(os.getenv("PASS_RESET_KEY"))
         self.bcrypt = Bcrypt()
@@ -26,16 +30,20 @@ class ChangePasswordView(MethodView):
         if not company:
             return render_template('error.html', message=f"Empresa no encontrada: {company_short_name}"), 404
 
+        branding_data = self.branding_service.get_company_branding(company)
+
         try:
             # Decodificar el token
             email = self.serializer.loads(token, salt='password-reset', max_age=3600)
         except SignatureExpired as e:
             return render_template('forgot_password.html',
+                                   branding=branding_data,
                         alert_message="El enlace de cambio de contraseña ha expirado. Por favor, solicita uno nuevo.")
 
         return render_template('change_password.html',
                                company_short_name=company_short_name,
                                company=company,
+                               branding=branding_data,
                                token=token, email=email)
 
     def post(self, company_short_name: str, token: str):
@@ -44,6 +52,7 @@ class ChangePasswordView(MethodView):
         if not company:
             return render_template('error.html', message=f"Empresa no encontrada: {company_short_name}"), 404
 
+        branding_data = self.branding_service.get_company_branding(company)
         try:
             # Decodificar el token
             email = self.serializer.loads(token, salt='password-reset', max_age=3600)
@@ -51,6 +60,7 @@ class ChangePasswordView(MethodView):
             return render_template('forgot_password.html',
                                    company_short_name=company_short_name,
                                    company=company,
+                                   branding=branding_data,
                                     alert_message="El enlace de cambio de contraseña ha expirado. Por favor, solicita uno nuevo.")
 
         try:
@@ -72,17 +82,16 @@ class ChangePasswordView(MethodView):
                     token=token,
                     company_short_name=company_short_name,
                     company=company,
+                    branding=branding_data,
                     form_data={"temp_code": temp_code,
                                "new_password": new_password,
                                "confirm_password": confirm_password},
                     alert_message=response["error"]), 400
 
-
-            return render_template('login.html',
-                                   company_short_name=company_short_name,
-                                   company=company,
-                                   alert_icon='success',
-                               alert_message="Tu contraseña ha sido restablecida exitosamente. Ahora puedes iniciar sesión.")
+            # Éxito: Guardar mensaje en sesión y redirigir
+            session['alert_message'] = "Tu contraseña ha sido restablecida exitosamente. Ahora puedes iniciar sesión."
+            session['alert_icon'] = 'success'
+            return redirect(url_for('index', company_short_name=company_short_name))
 
         except Exception as e:
             return render_template("error.html",
